const chai = require('chai');
const sinon = require('sinon');

const {request, response} = require('express');

describe('pg', () => {
	it('should return a Krauter with an executor function that correctly parses ', () => {
		
		const expected = {
			query: 'SELECT * FROM merchants WHERE id = $1',
			id: 42,
			result: [{'id': 42, 'name': 'Amazon'}]
		};
		
		const conn = {
			query: sinon.stub().withArgs(expected.query, [expected.id]).returns(expected.result)
		};
		
		const api = require('..').pg(conn);
		api.get('/merchants/:id', 'SELECT * FROM merchants WHERE id = :params.id:');
		
		const req = Object.create(request, {method: 'get', url: '/merchants/42'});
		const res = Object.create(response);
		sinon.spy(res, 'end');
		const next = sinon.spy();
		api(req, res, next);
		
		sinon.assert.calledOnce(conn.query);
		sinon.assert.calledWithExactly(conn.query, query, [42]);
		
		sinon.assert.calledOnce(res.end);
		sinon.assert.notCalled(next);
		
	});
});

